@@ -1,25 +1,28 @@
 var searchData=
 [
-  ['max',['max',['../a00312.html#a518dc4009aefe63f5e78b3275e2b6680',1,'VectorT::max() const '],['../a00312.html#a6513fe7b637053b7bddc63dedce4d718',1,'VectorT::max(const vector_type &amp;_rhs) const '],['../a00236.html#a32710b6611b5b17a5ecc25b076977bf1',1,'OpenMesh::Utils::NumLimitsT::max()']]],
-  ['max_5fabs',['max_abs',['../a00312.html#ac26e4238e21c149972f183420cbd6ac8',1,'VectorT']]],
+  ['makepropertymanagerfromexisting',['makePropertyManagerFromExisting',['../a00734.html#a5c51922351a904ba9989ad017ea089fa',1,'OpenMesh']]],
+  ['makepropertymanagerfromexistingornew',['makePropertyManagerFromExistingOrNew',['../a00734.html#aaff8443626d90aad63e73556ffa17f85',1,'OpenMesh']]],
+  ['makepropertymanagerfromnew',['makePropertyManagerFromNew',['../a00734.html#a385106056e6d718ed26bd922e6378599',1,'OpenMesh']]],
+  ['max',['max',['../a00313.html#a518dc4009aefe63f5e78b3275e2b6680',1,'VectorT::max() const '],['../a00313.html#a6513fe7b637053b7bddc63dedce4d718',1,'VectorT::max(const vector_type &amp;_rhs) const '],['../a00236.html#a32710b6611b5b17a5ecc25b076977bf1',1,'OpenMesh::Utils::NumLimitsT::max()']]],
+  ['max_5fabs',['max_abs',['../a00313.html#ac26e4238e21c149972f183420cbd6ac8',1,'VectorT']]],
   ['max_5fangle',['max_angle',['../a00235.html#ab5026b4a5db7a2bf6a795544081c93b2',1,'OpenMesh::NormalConeT::max_angle(const Vec3 &amp;) const '],['../a00235.html#a0634eb78ca82616573d989f2bfafde9e',1,'OpenMesh::NormalConeT::max_angle(const NormalConeT &amp;) const ']]],
   ['max_5ferr',['max_err',['../a00228.html#a32cd14801e16d308d2cdae825c77de20',1,'OpenMesh::Decimater::ModQuadricT']]],
   ['max_5fnormal_5fdeviation',['max_normal_deviation',['../a00226.html#ae0152e836e48b493a1f0dcaba0bff199',1,'OpenMesh::Decimater::ModNormalFlippingT']]],
-  ['maximize',['maximize',['../a00312.html#aa31e5aa9a9b6651b1fe3718727deee9d',1,'VectorT']]],
-  ['maximized',['maximized',['../a00312.html#a0df8311e00ff433263c1a21dcd7e7106',1,'VectorT']]],
+  ['maximize',['maximize',['../a00313.html#aa31e5aa9a9b6651b1fe3718727deee9d',1,'VectorT']]],
+  ['maximized',['maximized',['../a00313.html#a0df8311e00ff433263c1a21dcd7e7106',1,'VectorT']]],
   ['mcdecimatert',['McDecimaterT',['../a00203.html#afe1195415c6af21ccf2a887311f049ed',1,'OpenMesh::Decimater::McDecimaterT']]],
-  ['mean',['mean',['../a00312.html#a06f6a6e6ecb327c85757a16035d832ad',1,'VectorT']]],
-  ['mean_5fabs',['mean_abs',['../a00312.html#a8d2a5aefca80065de46bdb28bda7e7e6',1,'VectorT']]],
+  ['mean',['mean',['../a00313.html#a06f6a6e6ecb327c85757a16035d832ad',1,'VectorT']]],
+  ['mean_5fabs',['mean_abs',['../a00313.html#a8d2a5aefca80065de46bdb28bda7e7e6',1,'VectorT']]],
   ['merge',['merge',['../a00235.html#a6fd9ba88a9b0049a91429a87c73862ec',1,'OpenMesh::NormalConeT']]],
   ['mesh',['mesh',['../a00091.html#aa5d6598dced77ec6d97823559a3e58dc',1,'OpenMesh::Decimater::BaseDecimaterT::mesh()'],['../a00219.html#a4b4ef38dac53440f7a01402a6844722a',1,'OpenMesh::Decimater::ModBaseT::mesh()']]],
-  ['mesh_5fcast',['mesh_cast',['../a00731.html#ac0f75aab1c554cfcdf72a61c09d1ab36',1,'OpenMesh']]],
+  ['mesh_5fcast',['mesh_cast',['../a00734.html#ac0f75aab1c554cfcdf72a61c09d1ab36',1,'OpenMesh']]],
   ['meshcheckert',['MeshCheckerT',['../a00210.html#ab8f81f809bef0cecd4fc537a6319588f',1,'OpenMesh::Utils::MeshCheckerT']]],
   ['meshviewerwidget',['MeshViewerWidget',['../a00214.html#ac9c2d9965e20c5af25478cde6d3f72de',1,'MeshViewerWidget::MeshViewerWidget(QWidget *parent=0)'],['../a00214.html#abb3882da8de0f1d08d652a14313e9515',1,'MeshViewerWidget::MeshViewerWidget(QWidget *_parent=0)']]],
   ['meshviewerwidgett',['MeshViewerWidgetT',['../a00215.html#a04b4b037fd57ae7f6c884274a369b3aa',1,'MeshViewerWidgetT']]],
-  ['min',['min',['../a00312.html#a17547bec9dea921d7193030b52cd58ec',1,'VectorT::min() const '],['../a00312.html#aad929877409234a43f0e79fc137d40ac',1,'VectorT::min(const vector_type &amp;_rhs) const '],['../a00236.html#a88db07419fbf5a3797f799901ccd7959',1,'OpenMesh::Utils::NumLimitsT::min()']]],
-  ['min_5fabs',['min_abs',['../a00312.html#ac2ec0cc3933bb89ddbaa73da0d346555',1,'VectorT']]],
-  ['minimize',['minimize',['../a00312.html#a3871f2fc81117406465b7c6d045f6d4e',1,'VectorT']]],
-  ['minimized',['minimized',['../a00312.html#a4e6e0439315dc8951e47f4c96e604662',1,'VectorT']]],
+  ['min',['min',['../a00313.html#a17547bec9dea921d7193030b52cd58ec',1,'VectorT::min() const '],['../a00313.html#aad929877409234a43f0e79fc137d40ac',1,'VectorT::min(const vector_type &amp;_rhs) const '],['../a00236.html#a88db07419fbf5a3797f799901ccd7959',1,'OpenMesh::Utils::NumLimitsT::min()']]],
+  ['min_5fabs',['min_abs',['../a00313.html#ac2ec0cc3933bb89ddbaa73da0d346555',1,'VectorT']]],
+  ['minimize',['minimize',['../a00313.html#a3871f2fc81117406465b7c6d045f6d4e',1,'VectorT']]],
+  ['minimized',['minimized',['../a00313.html#a4e6e0439315dc8951e47f4c96e604662',1,'VectorT']]],
   ['mixeddecimatert',['MixedDecimaterT',['../a00216.html#a3d9cb8dbee8294357f1ca9003f08d3a8',1,'OpenMesh::Decimater::MixedDecimaterT']]],
   ['modaspectratiot',['ModAspectRatioT',['../a00217.html#a5a97855647addc932e36aaee7b9d3cb0',1,'OpenMesh::Decimater::ModAspectRatioT']]],
   ['modbalancert',['ModBalancerT',['../a00218.html#a35c84643ccb29982bd43ef790179be91',1,'ModBalancerT']]],
