@@ -445,37 +445,251 @@ TEST_F(OpenMeshReadWritePLY, LoadSimplePLYWithNormals) {
  */
 TEST_F(OpenMeshReadWritePLY, LoadSimplePLYWithCustomProps) {
 
-    mesh_.clear();
+    PolyMesh mesh;
 
     OpenMesh::IO::Options options;
     options += OpenMesh::IO::Options::Custom;
 
-    bool ok = OpenMesh::IO::read_mesh(mesh_, "cube-minimal-custom_props.ply", options);
+    bool ok = OpenMesh::IO::read_mesh(mesh, "cube-minimal-custom_props.ply", options);
 
     EXPECT_TRUE(ok) << "Unable to load cube-minimal-custom_props.ply";
 
-    EXPECT_EQ(8u  , mesh_.n_vertices()) << "The number of loaded vertices is not correct!";
-    EXPECT_EQ(18u , mesh_.n_edges()) << "The number of loaded edges is not correct!";
-    EXPECT_EQ(12u , mesh_.n_faces()) << "The number of loaded faces is not correct!";
+    EXPECT_EQ(8u  , mesh.n_vertices()) << "The number of loaded vertices is not correct!";
+    EXPECT_EQ(12u , mesh.n_edges()) << "The number of loaded edges is not correct!";
+    EXPECT_EQ(6u , mesh.n_faces()) << "The number of loaded faces is not correct!";
 
     OpenMesh::VPropHandleT<float> qualityProp;
     OpenMesh::VPropHandleT<unsigned int> indexProp;
-    EXPECT_TRUE(mesh_.get_property_handle(qualityProp,"quality")) << "Could not access quality property";
-    EXPECT_TRUE(mesh_.get_property_handle(indexProp,"index")) << "Could not access index property";
+    ASSERT_TRUE(mesh.get_property_handle(qualityProp,"quality")) << "Could not access quality property";
+    ASSERT_TRUE(mesh.get_property_handle(indexProp,"index")) << "Could not access index property";
 
     //check index property
-    for (unsigned i = 0; i < mesh_.n_vertices(); ++i)
-      EXPECT_EQ(i ,mesh_.property(indexProp,OpenMesh::VertexHandle(i))) << "Vertex index at vertex " << i << " is wrong";
+    for (unsigned i = 0; i < mesh.n_vertices(); ++i)
+      EXPECT_EQ(i ,mesh.property(indexProp,OpenMesh::VertexHandle(i))) << "Vertex index at vertex " << i << " is wrong";
 
     //check quality property
-    EXPECT_EQ(1.f,mesh_.property(qualityProp,OpenMesh::VertexHandle(0))) << "Wrong quality value at Vertex 0";
-    EXPECT_EQ(0.5f,mesh_.property(qualityProp,OpenMesh::VertexHandle(1))) << "Wrong quality value at Vertex 1";
-    EXPECT_EQ(0.7f,mesh_.property(qualityProp,OpenMesh::VertexHandle(2))) << "Wrong quality value at Vertex 2";
-    EXPECT_EQ(1.f,mesh_.property(qualityProp,OpenMesh::VertexHandle(3))) << "Wrong quality value at Vertex 3";
-    EXPECT_EQ(0.1f,mesh_.property(qualityProp,OpenMesh::VertexHandle(4))) << "Wrong quality value at Vertex 4";
-    EXPECT_EQ(0.f,mesh_.property(qualityProp,OpenMesh::VertexHandle(5))) << "Wrong quality value at Vertex 5";
-    EXPECT_EQ(2.f,mesh_.property(qualityProp,OpenMesh::VertexHandle(6))) << "Wrong quality value at Vertex 6";
-    EXPECT_EQ(5.f,mesh_.property(qualityProp,OpenMesh::VertexHandle(7))) << "Wrong quality value at Vertex 7";
+    EXPECT_EQ(1.f,mesh.property(qualityProp,OpenMesh::VertexHandle(0))) << "Wrong quality value at Vertex 0";
+    EXPECT_EQ(0.5f,mesh.property(qualityProp,OpenMesh::VertexHandle(1))) << "Wrong quality value at Vertex 1";
+    EXPECT_EQ(0.7f,mesh.property(qualityProp,OpenMesh::VertexHandle(2))) << "Wrong quality value at Vertex 2";
+    EXPECT_EQ(1.f,mesh.property(qualityProp,OpenMesh::VertexHandle(3))) << "Wrong quality value at Vertex 3";
+    EXPECT_EQ(0.1f,mesh.property(qualityProp,OpenMesh::VertexHandle(4))) << "Wrong quality value at Vertex 4";
+    EXPECT_EQ(0.f,mesh.property(qualityProp,OpenMesh::VertexHandle(5))) << "Wrong quality value at Vertex 5";
+    EXPECT_EQ(2.f,mesh.property(qualityProp,OpenMesh::VertexHandle(6))) << "Wrong quality value at Vertex 6";
+    EXPECT_EQ(5.f,mesh.property(qualityProp,OpenMesh::VertexHandle(7))) << "Wrong quality value at Vertex 7";
+
+    //check for custom list properties
+
+    OpenMesh::VPropHandleT< std::vector<int> > testValues;
+    ASSERT_TRUE(mesh.get_property_handle(testValues,"test_values")) << "Could not access texcoords per face";
+
+    EXPECT_EQ(2u,mesh.property(testValues,OpenMesh::VertexHandle(0)).size()) << "Wrong verctor size";
+
+    EXPECT_EQ(1,mesh.property(testValues,OpenMesh::VertexHandle(0))[0]) << "Wrong list value at Vertex 0";
+    EXPECT_EQ(4,mesh.property(testValues,OpenMesh::VertexHandle(1))[1]) << "Wrong list value at Vertex 1";
+    EXPECT_EQ(5,mesh.property(testValues,OpenMesh::VertexHandle(2))[0]) << "Wrong list value at Vertex 2";
+    EXPECT_EQ(8,mesh.property(testValues,OpenMesh::VertexHandle(3))[1]) << "Wrong list value at Vertex 3";
+    EXPECT_EQ(9,mesh.property(testValues,OpenMesh::VertexHandle(4))[0]) << "Wrong list value at Vertex 4";
+    EXPECT_EQ(12,mesh.property(testValues,OpenMesh::VertexHandle(5))[1]) << "Wrong list value at Vertex 5";
+    EXPECT_EQ(13,mesh.property(testValues,OpenMesh::VertexHandle(6))[0]) << "Wrong list value at Vertex 6";
+    EXPECT_EQ(16,mesh.property(testValues,OpenMesh::VertexHandle(7))[1]) << "Wrong list value at Vertex 7";
+
+    OpenMesh::FPropHandleT< std::vector<float> > texCoordsPerFace;
+    ASSERT_TRUE(mesh.get_property_handle(texCoordsPerFace,"texcoords")) << "Could not access texcoords per face";
+
+    for (Mesh::FaceIter f_iter = mesh.faces_begin(); f_iter != mesh.faces_end(); ++f_iter)
+    {
+      EXPECT_EQ(8u, mesh.property(texCoordsPerFace, *f_iter).size()) << "Texcoords per face container has wrong size on face: " << f_iter->idx();
+      if (!mesh.property(texCoordsPerFace, *f_iter).empty())
+      {
+        EXPECT_EQ(1.0, mesh.property(texCoordsPerFace, *f_iter)[0]) << "Texcoords wrong on index 0 with face: " << f_iter->idx();
+        EXPECT_EQ(1.0, mesh.property(texCoordsPerFace, *f_iter)[1]) << "Texcoords wrong on index 1 with face: " << f_iter->idx();
+        EXPECT_EQ(-1.0f, mesh.property(texCoordsPerFace, *f_iter)[2]) << "Texcoords wrong on index 2 with face: " << f_iter->idx();
+        EXPECT_EQ(-1.0f, mesh.property(texCoordsPerFace, *f_iter)[3]) << "Texcoords wrong on index 3 with face: " << f_iter->idx();
+        EXPECT_EQ(0.0f, mesh.property(texCoordsPerFace, *f_iter)[4]) << "Texcoords wrong on index 4 with face: " << f_iter->idx();
+        EXPECT_EQ(0.0f, mesh.property(texCoordsPerFace, *f_iter)[5]) << "Texcoords wrong on index 5 with face: " << f_iter->idx();
+        EXPECT_EQ(-0.5f, mesh.property(texCoordsPerFace, *f_iter)[6]) << "Texcoords wrong on index 6 with face: " << f_iter->idx();
+        EXPECT_EQ(-0.5f, mesh.property(texCoordsPerFace, *f_iter)[7]) << "Texcoords wrong on index 7 with face: " << f_iter->idx();
+      }
+
+    }
+
+    OpenMesh::FPropHandleT< unsigned > faceIndex;
+    ASSERT_TRUE(mesh.get_property_handle(faceIndex,"faceIndex")) << "Could not access faceIndex per face";
+
+    EXPECT_EQ(0u,mesh.property(faceIndex,OpenMesh::FaceHandle(0))) << "Wrong index value at FaceHandle 0";
+    EXPECT_EQ(1u,mesh.property(faceIndex,OpenMesh::FaceHandle(1))) << "Wrong index value at FaceHandle 1";
+    EXPECT_EQ(2u,mesh.property(faceIndex,OpenMesh::FaceHandle(2))) << "Wrong index value at FaceHandle 2";
+    EXPECT_EQ(3u,mesh.property(faceIndex,OpenMesh::FaceHandle(3))) << "Wrong index value at FaceHandle 3";
+    EXPECT_EQ(4u,mesh.property(faceIndex,OpenMesh::FaceHandle(4))) << "Wrong index value at FaceHandle 4";
+    EXPECT_EQ(5u,mesh.property(faceIndex,OpenMesh::FaceHandle(5))) << "Wrong index value at FaceHandle 5";
+
+}
+
+
+TEST_F(OpenMeshReadWritePLY, WriteReadSimplePLYWithCustomProps) {
+
+    PolyMesh mesh;
+
+    OpenMesh::IO::Options options;
+    bool ok = OpenMesh::IO::read_mesh(mesh, "cube-minimal.ply", options);
+
+
+    OpenMesh::VPropHandleT<unsigned short> indexProp;
+    OpenMesh::VPropHandleT<unsigned int> nonPersistant;
+    OpenMesh::VPropHandleT<double> qualityProp;
+    OpenMesh::FPropHandleT<signed int> faceProp;
+    OpenMesh::VPropHandleT<int> removedProp;
+
+    const std::string indexPropName = "mySuperIndexProperty";
+    const std::string qualityPropName = "quality";
+    const std::string facePropName = "anotherPropForFaces";
+    const std::string nonPersistantName = "nonPersistant";
+    const std::string removedPropName = "willBeRemoved";
+
+    mesh.add_property(indexProp,indexPropName);
+    mesh.add_property(qualityProp,qualityPropName);
+    mesh.add_property(removedProp, removedPropName);
+    mesh.add_property(faceProp,facePropName);
+    mesh.add_property(nonPersistant,nonPersistantName);
+
+    mesh.property(indexProp).set_persistent(true);
+    mesh.property(qualityProp).set_persistent(true);
+    mesh.property(faceProp).set_persistent(true);
+    mesh.remove_property(removedProp);
+
+    signed char i=0;
+    for (Mesh::VertexIter v_iter = mesh.vertices_begin(); v_iter != mesh.vertices_end(); ++v_iter, ++i)
+    {
+      mesh.property(indexProp, *v_iter) = i;
+      mesh.property(qualityProp, *v_iter) = 3.5*i;
+    }
+
+    i = 0;
+    for (Mesh::FaceIter f_iter = mesh.faces_begin(); f_iter != mesh.faces_end(); ++f_iter, ++i)
+    {
+      mesh.property(faceProp, *f_iter) = -i;
+    }
+
+    const char* outFilename = "cube-minimal-customprops_openmeshOutputTestfile.ply";
+    ok = OpenMesh::IO::write_mesh(mesh, outFilename);
+
+    ASSERT_TRUE(ok);
+
+    PolyMesh loadedMesh;
+
+    EXPECT_FALSE(loadedMesh.get_property_handle(indexProp,indexPropName)) << "Could access to property which was deleted";
+
+    options += OpenMesh::IO::Options::Custom;
+    ok = OpenMesh::IO::read_mesh(loadedMesh, outFilename, options);
+
+    ASSERT_TRUE(ok);
+
+
+    ASSERT_TRUE(loadedMesh.get_property_handle(indexProp,indexPropName)) << "Could not access index property";
+    ASSERT_TRUE(loadedMesh.get_property_handle(qualityProp,qualityPropName)) << "Could not access quality property";
+    ASSERT_TRUE(loadedMesh.get_property_handle(faceProp,facePropName)) << "Could not access face property";
+    EXPECT_FALSE(loadedMesh.get_property_handle(nonPersistant,nonPersistantName)) << "Could access non persistant property";
+
+    i=0;
+    for (Mesh::VertexIter v_iter = loadedMesh.vertices_begin(); v_iter != loadedMesh.vertices_end(); ++v_iter, ++i)
+    {
+      EXPECT_EQ(loadedMesh.property(indexProp, *v_iter), static_cast<unsigned>(i));
+      EXPECT_EQ(loadedMesh.property(qualityProp, *v_iter),3.5*i);
+    }
+
+    i = 0;
+    for (Mesh::FaceIter f_iter = loadedMesh.faces_begin(); f_iter != loadedMesh.faces_end(); ++f_iter, ++i)
+    {
+      EXPECT_EQ(loadedMesh.property(faceProp, *f_iter),-i);
+    }
+
+
+    remove(outFilename);
+
+}
+
+TEST_F(OpenMeshReadWritePLY, WriteReadBinaryPLYWithCustomProps) {
+
+    PolyMesh mesh;
+
+    OpenMesh::IO::Options options;
+    bool ok = OpenMesh::IO::read_mesh(mesh, "cube-minimal.ply", options);
+
+
+    OpenMesh::VPropHandleT<unsigned short> indexProp;
+    OpenMesh::VPropHandleT<unsigned int> nonPersistant;
+    OpenMesh::VPropHandleT<double> qualityProp;
+    OpenMesh::FPropHandleT<signed int> faceProp;
+    OpenMesh::VPropHandleT<int> removedProp;
+
+    const std::string indexPropName = "mySuperIndexProperty";
+    const std::string qualityPropName = "quality";
+    const std::string facePropName = "anotherPropForFaces";
+    const std::string nonPersistantName = "nonPersistant";
+    const std::string removedPropName = "willBeRemoved";
+
+    mesh.add_property(indexProp,indexPropName);
+    mesh.add_property(qualityProp,qualityPropName);
+    mesh.add_property(removedProp, removedPropName);
+    mesh.add_property(faceProp,facePropName);
+    mesh.add_property(nonPersistant,nonPersistantName);
+
+    mesh.property(indexProp).set_persistent(true);
+    mesh.property(qualityProp).set_persistent(true);
+    mesh.property(faceProp).set_persistent(true);
+    mesh.remove_property(removedProp);
+
+    signed char i=0;
+    for (Mesh::VertexIter v_iter = mesh.vertices_begin(); v_iter != mesh.vertices_end(); ++v_iter, ++i)
+    {
+      mesh.property(indexProp, *v_iter) = i;
+      mesh.property(qualityProp, *v_iter) = 3.5*i;
+    }
+
+    i = 0;
+    for (Mesh::FaceIter f_iter = mesh.faces_begin(); f_iter != mesh.faces_end(); ++f_iter, ++i)
+    {
+      mesh.property(faceProp, *f_iter) = -i;
+    }
+
+    const char* outFilename = "cube-minimal-customprops_openmeshOutputTestfileBinary.ply";
+    options += OpenMesh::IO::Options::Binary;
+    ok = OpenMesh::IO::write_mesh(mesh, outFilename, options);
+
+    ASSERT_TRUE(ok);
+
+    PolyMesh loadedMesh;
+
+    EXPECT_FALSE(loadedMesh.get_property_handle(indexProp,indexPropName)) << "Could access to property which was deleted";
+
+    options.clear();
+    options += OpenMesh::IO::Options::Custom;
+    options += OpenMesh::IO::Options::Binary;
+    ok = OpenMesh::IO::read_mesh(loadedMesh, outFilename, options);
+
+    ASSERT_TRUE(ok);
+
+
+    ASSERT_TRUE(loadedMesh.get_property_handle(indexProp,indexPropName)) << "Could not access index property";
+    ASSERT_TRUE(loadedMesh.get_property_handle(qualityProp,qualityPropName)) << "Could not access quality property";
+    ASSERT_TRUE(loadedMesh.get_property_handle(faceProp,facePropName)) << "Could not access face property";
+    EXPECT_FALSE(loadedMesh.get_property_handle(nonPersistant,nonPersistantName)) << "Could access non persistant property";
+
+    i=0;
+    for (Mesh::VertexIter v_iter = loadedMesh.vertices_begin(); v_iter != loadedMesh.vertices_end(); ++v_iter, ++i)
+    {
+      EXPECT_EQ(loadedMesh.property(indexProp, *v_iter), static_cast<unsigned>(i));
+      EXPECT_EQ(loadedMesh.property(qualityProp, *v_iter),3.5*i);
+    }
+
+    i = 0;
+    for (Mesh::FaceIter f_iter = loadedMesh.faces_begin(); f_iter != loadedMesh.faces_end(); ++f_iter, ++i)
+    {
+      EXPECT_EQ(loadedMesh.property(faceProp, *f_iter),-i);
+    }
+
+
+    //remove(outFilename);
 
 }
 }
